==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/TlsCertificateConfig.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) A wrapper for the tls config returned by {@link TlsCertificate.bind}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.106Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.TlsCertificateConfig")
@software.amazon.jsii.Jsii.Proxy(TlsCertificateConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TlsCertificateConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The CFN shape for a listener TLS certificate.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty getTlsCertificate();

    /**
     * (experimental) The TLS mode.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.TlsMode getTlsMode();

    /**
     * @return a {@link Builder} of {@link TlsCertificateConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TlsCertificateConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TlsCertificateConfig> {
        private software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate;
        private software.amazon.awscdk.services.appmesh.TlsMode tlsMode;

        /**
         * Sets the value of {@link TlsCertificateConfig#getTlsCertificate}
         * @param tlsCertificate The CFN shape for a listener TLS certificate. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tlsCertificate(software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate) {
            this.tlsCertificate = tlsCertificate;
            return this;
        }

        /**
         * Sets the value of {@link TlsCertificateConfig#getTlsMode}
         * @param tlsMode The TLS mode. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tlsMode(software.amazon.awscdk.services.appmesh.TlsMode tlsMode) {
            this.tlsMode = tlsMode;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TlsCertificateConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TlsCertificateConfig build() {
            return new Jsii$Proxy(tlsCertificate, tlsMode);
        }
    }

    /**
     * An implementation for {@link TlsCertificateConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TlsCertificateConfig {
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate;
        private final software.amazon.awscdk.services.appmesh.TlsMode tlsMode;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.tlsCertificate = software.amazon.jsii.Kernel.get(this, "tlsCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty.class));
            this.tlsMode = software.amazon.jsii.Kernel.get(this, "tlsMode", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.TlsMode.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate, final software.amazon.awscdk.services.appmesh.TlsMode tlsMode) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.tlsCertificate = java.util.Objects.requireNonNull(tlsCertificate, "tlsCertificate is required");
            this.tlsMode = java.util.Objects.requireNonNull(tlsMode, "tlsMode is required");
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty getTlsCertificate() {
            return this.tlsCertificate;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.TlsMode getTlsMode() {
            return this.tlsMode;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("tlsCertificate", om.valueToTree(this.getTlsCertificate()));
            data.set("tlsMode", om.valueToTree(this.getTlsMode()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.TlsCertificateConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TlsCertificateConfig.Jsii$Proxy that = (TlsCertificateConfig.Jsii$Proxy) o;

            if (!tlsCertificate.equals(that.tlsCertificate)) return false;
            return this.tlsMode.equals(that.tlsMode);
        }

        @Override
        public final int hashCode() {
            int result = this.tlsCertificate.hashCode();
            result = 31 * result + (this.tlsMode.hashCode());
            return result;
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/TlsCertificateConfig.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * A wrapper for the tls config returned by {@link TlsCertificate.bind}.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.appmesh.*;
 * TlsCertificateConfig tlsCertificateConfig = TlsCertificateConfig.builder()
 *         .tlsCertificate(ListenerTlsCertificateProperty.builder()
 *                 .acm(ListenerTlsAcmCertificateProperty.builder()
 *                         .certificateArn("certificateArn")
 *                         .build())
 *                 .file(ListenerTlsFileCertificateProperty.builder()
 *                         .certificateChain("certificateChain")
 *                         .privateKey("privateKey")
 *                         .build())
 *                 .sds(ListenerTlsSdsCertificateProperty.builder()
 *                         .secretName("secretName")
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.342Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.TlsCertificateConfig")
@software.amazon.jsii.Jsii.Proxy(TlsCertificateConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface TlsCertificateConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The CFN shape for a TLS certificate.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty getTlsCertificate();

    /**
     * @return a {@link Builder} of {@link TlsCertificateConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TlsCertificateConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<TlsCertificateConfig> {
        software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate;

        /**
         * Sets the value of {@link TlsCertificateConfig#getTlsCertificate}
         * @param tlsCertificate The CFN shape for a TLS certificate. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tlsCertificate(software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate) {
            this.tlsCertificate = tlsCertificate;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TlsCertificateConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public TlsCertificateConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TlsCertificateConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TlsCertificateConfig {
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty tlsCertificate;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.tlsCertificate = software.amazon.jsii.Kernel.get(this, "tlsCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.tlsCertificate = java.util.Objects.requireNonNull(builder.tlsCertificate, "tlsCertificate is required");
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.ListenerTlsCertificateProperty getTlsCertificate() {
            return this.tlsCertificate;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("tlsCertificate", om.valueToTree(this.getTlsCertificate()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.TlsCertificateConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TlsCertificateConfig.Jsii$Proxy that = (TlsCertificateConfig.Jsii$Proxy) o;

            return this.tlsCertificate.equals(that.tlsCertificate);
        }

        @Override
        public final int hashCode() {
            int result = this.tlsCertificate.hashCode();
            return result;
        }
    }
}
